@@ -24,7 +24,7 @@ class AttrTypeTests(FactoryTestCase):
         self.assertEqual(int, attr_type.native_type)
 
     def test_non_native_property(self):
-        attr_type = AttrTypeFactory.create(name="foo")
+        attr_type = AttrTypeFactory.create(qname="foo")
         self.assertIsNone(attr_type.native_name)
         self.assertIsNone(attr_type.native_code)
         self.assertIsNone(attr_type.native_type)
