@@ -2,24 +2,34 @@ import random
 import unittest
 from abc import ABC
 from abc import abstractmethod
+from typing import Type
 
 from xsdata.codegen.models import Attr
+from xsdata.codegen.models import AttrChoice
 from xsdata.codegen.models import AttrType
 from xsdata.codegen.models import Class
 from xsdata.codegen.models import Extension
-from xsdata.codegen.models import Package
+from xsdata.codegen.models import Import
 from xsdata.codegen.models import Restrictions
-from xsdata.models.elements import Attribute
-from xsdata.models.elements import ComplexType
-from xsdata.models.elements import Element
-from xsdata.models.elements import Restriction
-from xsdata.models.elements import SimpleType
+from xsdata.codegen.models import Status
 from xsdata.models.enums import DataType
 from xsdata.models.enums import Namespace
 from xsdata.models.enums import QNames
 from xsdata.models.enums import Tag
+from xsdata.models.wsdl import BindingOperation
+from xsdata.models.xsd import Attribute
+from xsdata.models.xsd import ComplexType
+from xsdata.models.xsd import Element
+from xsdata.models.xsd import Restriction
+from xsdata.models.xsd import SimpleType
+from xsdata.utils.namespaces import build_qname
 
-NSMAP = {ns.prefix: ns.uri for ns in Namespace}
+DEFAULT_NS_MAP = {
+    Namespace.XS.prefix: Namespace.XS.uri,
+    Namespace.XSI.prefix: Namespace.XSI.uri,
+    Namespace.XML.prefix: Namespace.XML.uri,
+    Namespace.XLINK.prefix: Namespace.XLINK.uri,
+}
 
 
 class FactoryTestCase(unittest.TestCase):
@@ -27,9 +37,9 @@ class FactoryTestCase(unittest.TestCase):
         super().setUp()
         ClassFactory.reset()
         AttrFactory.reset()
+        AttrChoiceFactory.reset()
         AttrTypeFactory.reset()
         ExtensionFactory.reset()
-        RestrictionsFactory.reset()
         PackageFactory.reset()
 
 
@@ -52,7 +62,7 @@ class Factory(ABC):
 
     @classmethod
     def list(cls, number: int, **kwargs):
-        return [cls.create(**kwargs) for i in range(number)]
+        return [cls.create(**kwargs) for _ in range(number)]
 
 
 class ClassFactory(Factory):
@@ -63,13 +73,14 @@ class ClassFactory(Factory):
     @classmethod
     def create(
         cls,
-        name=None,
+        qname=None,
+        meta_name=None,
         namespace=None,
-        source_namespace="xsdata",
         type=None,
         abstract=False,
         mixed=False,
         nillable=False,
+        strict_type=False,
         help=None,
         extensions=None,
         substitutions=None,
@@ -78,16 +89,20 @@ class ClassFactory(Factory):
         ns_map=None,
         package="foo",
         module="tests",
-        processed=False,
+        status=Status.RAW,
+        container=None,
     ):
-        name = name or f"class_{cls.next_letter()}"
+        if not qname:
+            qname = build_qname("xsdata", f"class_{cls.next_letter()}")
+
         return cls.model(
-            name=name,
+            qname=qname,
+            meta_name=meta_name,
             namespace=namespace,
-            source_namespace=source_namespace,
             abstract=abstract,
             mixed=mixed,
             nillable=nillable,
+            strict_type=strict_type,
             type=type or random.choice(cls.types),
             extensions=extensions or [],
             substitutions=substitutions or [],
@@ -96,8 +111,17 @@ class ClassFactory(Factory):
             help=help,
             package=package,
             module=module,
-            ns_map=ns_map if isinstance(ns_map, dict) else NSMAP,
-            processed=processed,
+            ns_map=ns_map if isinstance(ns_map, dict) else DEFAULT_NS_MAP,
+            status=status,
+            container=container,
+        )
+
+    @classmethod
+    def simple_type(cls, **kwargs) -> Class:
+        return ClassFactory.create(
+            type=SimpleType,
+            attrs=AttrFactory.list(1, tag=Tag.EXTENSION),
+            **kwargs,
         )
 
     @classmethod
@@ -116,48 +140,10 @@ class ClassFactory(Factory):
             **kwargs,
         )
 
-
-class RestrictionsFactory(Factory):
-    model = Restrictions
-    counter = 65
-
     @classmethod
-    def create(
-        cls,
-        required=None,
-        min_occurs=None,
-        max_occurs=None,
-        min_exclusive=None,
-        min_inclusive=None,
-        min_length=None,
-        max_exclusive=None,
-        max_inclusive=None,
-        max_length=None,
-        total_digits=None,
-        fraction_digits=None,
-        length=None,
-        white_space=None,
-        pattern=None,
-        explicit_timezone=None,
-        nillable=None,
-    ):
-        return cls.model(
-            required=required,
-            min_occurs=min_occurs,
-            max_occurs=max_occurs,
-            min_exclusive=min_exclusive,
-            min_inclusive=min_inclusive,
-            min_length=min_length,
-            max_exclusive=max_exclusive,
-            max_inclusive=max_inclusive,
-            max_length=max_length,
-            total_digits=total_digits,
-            fraction_digits=fraction_digits,
-            length=length,
-            white_space=white_space,
-            pattern=pattern,
-            explicit_timezone=explicit_timezone,
-            nillable=nillable,
+    def service(cls, attributes: int, **kwargs) -> Class:
+        return ClassFactory.create(
+            type=BindingOperation, attrs=AttrFactory.list(attributes, tag=Tag.ELEMENT)
         )
 
 
@@ -169,7 +155,7 @@ class ExtensionFactory(Factory):
     def create(cls, type=None, restrictions=None):
         return cls.model(
             type=type or AttrTypeFactory.create(),
-            restrictions=restrictions or RestrictionsFactory.create(),
+            restrictions=restrictions or Restrictions(),
         )
 
 
@@ -180,17 +166,17 @@ class AttrTypeFactory(Factory):
     @classmethod
     def create(
         cls,
-        name=None,
-        index=None,
+        qname=None,
         alias=None,
         native=False,
         forward=False,
         circular=False,
     ):
+        if not qname:
+            qname = build_qname("xsdata", f"attr_{cls.next_letter()}")
 
         return cls.model(
-            name=name or f"attr_{cls.next_letter()}",
-            index=index or 0,
+            qname=str(qname),
             alias=alias,
             native=native,
             circular=circular,
@@ -199,47 +185,47 @@ class AttrTypeFactory(Factory):
 
     @classmethod
     def xs_string(cls):
-        return cls.create(name=DataType.STRING.code, native=True)
+        return cls.create(qname=DataType.STRING, native=True)
 
     @classmethod
     def xs_int(cls):
-        return cls.create(name=DataType.INTEGER.code, native=True)
+        return cls.create(qname=DataType.INTEGER, native=True)
 
     @classmethod
     def xs_positive_int(cls):
-        return cls.create(name=DataType.POSITIVE_INTEGER.code, native=True)
+        return cls.create(qname=DataType.POSITIVE_INTEGER, native=True)
 
     @classmethod
     def xs_float(cls):
-        return cls.create(name=DataType.FLOAT.code, native=True)
+        return cls.create(qname=DataType.FLOAT, native=True)
 
     @classmethod
     def xs_decimal(cls):
-        return cls.create(name=DataType.DECIMAL.code, native=True)
+        return cls.create(qname=DataType.DECIMAL, native=True)
 
     @classmethod
     def xs_bool(cls):
-        return cls.create(name=DataType.BOOLEAN.code, native=True)
+        return cls.create(qname=DataType.BOOLEAN, native=True)
 
     @classmethod
     def xs_any(cls):
-        return cls.create(name=DataType.ANY_TYPE.code, native=True)
-
-    @classmethod
-    def xs_qmap(cls):
-        return cls.create(name=DataType.QMAP.code, native=True)
+        return cls.create(qname=DataType.ANY_TYPE, native=True)
 
     @classmethod
     def xs_qname(cls):
-        return cls.create(name=DataType.QNAME.code, native=True)
+        return cls.create(qname=DataType.QNAME, native=True)
 
     @classmethod
     def xs_tokens(cls):
-        return cls.create(name=DataType.NMTOKENS.code, native=True)
+        return cls.create(qname=DataType.NMTOKENS, native=True)
+
+    @classmethod
+    def xs_error(cls):
+        return cls.create(qname=DataType.ERROR, native=True)
 
 
 class AttrFactory(Factory):
-    model = Attr
+    model: Type = Attr
     types = [Attribute, Element, Restriction]
     counter = 65
 
@@ -250,25 +236,29 @@ class AttrFactory(Factory):
         local_name=None,
         index=None,
         types=None,
+        choices=None,
         tag=None,
         namespace=None,
         help=None,
         default=None,
         fixed=False,
+        mixed=False,
         restrictions=None,
     ):
         name = name or f"attr_{cls.next_letter()}"
         return cls.model(
             name=name,
-            local_name=local_name or name,
+            local_name=name if local_name is None else local_name,
             index=cls.counter if index is None else index,
             types=types or [AttrTypeFactory.xs_string()],
+            choices=choices or [],
             tag=tag or random.choice(cls.types).__name__,
             namespace=namespace or None,
             help=help or None,
             default=default or None,
             fixed=fixed,
-            restrictions=restrictions or RestrictionsFactory.create(),
+            mixed=mixed,
+            restrictions=restrictions or Restrictions(),
         )
 
     @classmethod
@@ -286,7 +276,7 @@ class AttrFactory(Factory):
     @classmethod
     def any_attribute(cls, **kwargs) -> Attr:
         return cls.create(
-            tag=Tag.ANY_ATTRIBUTE, types=[AttrTypeFactory.xs_qmap()], **kwargs,
+            tag=Tag.ANY_ATTRIBUTE, types=[AttrTypeFactory.xs_any()], **kwargs
         )
 
     @classmethod
@@ -295,7 +285,11 @@ class AttrFactory(Factory):
 
     @classmethod
     def attribute_group(cls, **kwargs) -> Attr:
-        return cls.create(tag=Tag.ATTRIBUTE_GROUP, **kwargs)
+        return cls.create(
+            tag=Tag.ATTRIBUTE_GROUP,
+            types=[AttrTypeFactory.create(qname=kwargs.get("name"))],
+            **kwargs,
+        )
 
     @classmethod
     def group(cls, **kwargs) -> Attr:
@@ -309,8 +303,34 @@ class AttrFactory(Factory):
         return cls.attribute(**kwargs)
 
 
+class AttrChoiceFactory(AttrFactory):
+    model: Type = AttrChoice
+    tags = [Tag.ELEMENT, Tag.ANY]
+    counter = 65
+
+    @classmethod
+    def create(
+        cls,
+        name=None,
+        types=None,
+        tag=None,
+        namespace=None,
+        default=None,
+        restrictions=None,
+    ):
+        name = name or f"choice_{cls.next_letter()}"
+        return cls.model(
+            name=name,
+            types=types or [AttrTypeFactory.xs_string()],
+            tag=tag or random.choice(cls.tags),
+            namespace=namespace or None,
+            default=default or None,
+            restrictions=restrictions or Restrictions(),
+        )
+
+
 class PackageFactory(Factory):
-    model = Package
+    model = Import
     counter = 65
 
     @classmethod
