@@ -8,12 +8,12 @@ for xsd in files:
 
     content = xsd.read_text()
     if ":schema" not in content:
-        lines = content.split("\n")
+        lines = content.splitlines()
         pos = next(idx for idx, line in enumerate(lines) if not line.strip().startswith("<!--"))
         lines.insert(pos, root_start)
         lines.append(root_end)
 
-        xsd.write_text("\n".join(lines))
+        xsd.write_text("\n".join(lines), encoding="utf-8")
 
     if "-" in xsd.name:
         name = xsd.name.replace("-", "")
