@@ -3,24 +3,32 @@ from pathlib import Path
 from tests.factories import ClassFactory
 from tests.factories import FactoryTestCase
 from xsdata.formats.plantuml.generator import PlantUmlGenerator
+from xsdata.models.config import GeneratorConfig
 
 
 class PlantUmlGeneratorTests(FactoryTestCase):
+    def setUp(self):
+        super().setUp()
+        config = GeneratorConfig()
+        self.generator = PlantUmlGenerator(config)
+
     def test_render(self):
         classes = [
             ClassFactory.elements(2),
             ClassFactory.elements(3),
         ]
 
-        iterator = PlantUmlGenerator().render(classes)
+        iterator = self.generator.render(classes)
 
-        actual = [out for out in iterator]
+        actual = [(out.path, out.title, out.source) for out in iterator]
         self.assertEqual(1, len(actual))
         self.assertEqual(3, len(actual[0]))
         self.assertIsInstance(actual[0][0], Path)
         self.assertTrue(actual[0][0].is_absolute())
         self.assertEqual("foo.tests", actual[0][1])
-        self.assertEqual("foo/tests.pu", str(actual[0][0].relative_to(Path.cwd())))
+        self.assertEqual(
+            str(Path("foo/tests.pu")), str(actual[0][0].relative_to(Path.cwd()))
+        )
 
         output = """@startuml
 
