@@ -1,5 +1,6 @@
 import re
 
+# python allocated strings
 stop_words = [
     "and",
     "except",
@@ -41,10 +42,17 @@ stop_words = [
     "list",
     "optional",
     "dict",
+    "field",
 ]
 
 
 def safe_snake(string: str, default: str = "value") -> str:
+    """
+    Normalize the given string to make it safe for python source code.
+
+    Return or prepend the default value if after all filters the result
+    is invalid.
+    """
     if not string:
         return default
 
